/*
 * Copyright (c) 2001 David I. Bell
 * Permission is granted to use, distribute, or modify this source,
 * provided that this copyright notice remains intact.
 */

import java.io.FilterInputStream;
import java.io.InputStream;
import java.io.IOException;


/**
 * An input filter which counts the number of bytes received
 * using a Counter object.
 */
public class CounterInputFilter extends FilterInputStream
{
	protected Counter mCounter = new Counter();


	public CounterInputFilter(InputStream inputStream)
	{
		super(inputStream);
	}


	public void setCounter(Counter counter)
	{
		mCounter = counter;
	}


	public Counter getCounter()
	{
		return mCounter;
	}


	public int read() throws IOException
	{
		int data = in.read();

		if ((data >= 0) && (mCounter != null))
			mCounter.addCount(1);

		return data;
	}


	public int read(byte[] buffer) throws IOException
	{
		int count = in.read(buffer);

		if ((count > 0) && (mCounter != null))
			mCounter.addCount(count);

		return count;
	}


	public int read(byte[] buffer, int offset, int count)
		throws IOException
	{
		count = in.read(buffer, offset, count);

		if ((count > 0) && (mCounter != null))
			mCounter.addCount(count);

		return count;
	}


	public long skip(long count) throws IOException
	{
		throw new IOException("Skip method not implemented");
	}
}
