/*
 * Copyright (c) 2001 David I. Bell
 * Permission is granted to use, distribute, or modify this source,
 * provided that this copyright notice remains intact.
 */

import java.util.Vector;

import javax.swing.JTable;
import javax.swing.table.AbstractTableModel;


/**
 * A table model which understands connection information.
 */
public class SwingConnectionModel extends AbstractTableModel
{
	protected SwingManager mSwingManager;

	/**
	 * A vector of connections indexed by row number.
	 */
	protected Vector mConnectionVector = new Vector();


	public SwingConnectionModel(SwingManager manager)
	{
		mSwingManager = manager;
	}


	public void addConnection(SwingListener listener)
	{
		mConnectionVector.addElement(listener);
	}


	public void removeConnection(SwingListener listener)
	{
		mConnectionVector.remove(listener);
	}


	public int getRowCount()
	{
		return mConnectionVector.size();
	}


	/**
	 * Return the number of columns.
	 */
	public int getColumnCount()
	{
		return SwingListener.getColumnCount();
	}


	public Object getValueAt(int row, int column)
	{
		if ((row < 0) || (row >= mConnectionVector.size()))
			return "";

		SwingListener listener = (SwingListener) mConnectionVector.elementAt(row);

		return listener.getValueAt(column);
	}


	public String getColumnName(int column)
	{
		return SwingListener.getColumnName(column);
	}
}
