/*
 * Copyright (c) 2001 David I. Bell
 * Permission is granted to use, distribute, or modify this source,
 * provided that this copyright notice remains intact.
 */

/**
 * A listener interface for a TransferListener object which is called
 * when a Transferer has done some I/O. 
 */
public interface TransferListener
{
	/**
	 * Method called when the first line of the data has been read.
	 * This will be the URL and METHOD line from a client, or the
	 * STATUS line from the server.
	 */
	public void firstLineAvailable(Transferer transferer);


	/**
	 * Method called when all of the header lines have been read.
	 */
	public void headersAvailable(Transferer transferer);


	/**
	 * Method called on every read operation.
	 */
	public void didRead(Transferer transferer);


	/**
	 * Method called on every write operation.
	 */
	public void didWrite(Transferer transferer);
}
