/*
 * Copyright (c) 2001 David I. Bell
 * Permission is granted to use, distribute, or modify this source,
 * provided that this copyright notice remains intact.
 */

import java.net.Socket;
import java.io.InputStream;
import java.io.OutputStream;
import java.io.IOException;


/**
 * Static utility methods.
 */
public class Utils
{
	/**
	 * Close the specified socket and log errors.
	 * The supplied socket can be null.
	 */
	public static void safeClose(Socket socket)
	{
		if (socket == null)
			return;

		try
		{
			socket.close();
		}
		catch (Exception e)
		{
			System.err.println("Error closing socket: " + e);
		}
	}


	/**
	 * Close the specified input stream and log errors.
	 * The supplied input stream can be null.
	 */
	public static void safeClose(InputStream inputStream)
	{
		if (inputStream == null)
			return;

		try
		{
			inputStream.close();
		}
		catch (Exception e)
		{
			System.err.println("Error closing input stream: " + e);
		}
	}


	/**
	 * Close the specified output stream and log errors.
	 * The supplied output stream can be null.
	 */
	public static void safeClose(OutputStream outputStream)
	{
		if (outputStream == null)
			return;

		try
		{
			outputStream.close();
		}
		catch (Exception e)
		{
			System.err.println("Error closing output stream: " + e);
		}
	}
}
